#include <iostream>
#include <string>

#include "BitmapImage.h"
#include "bssAztecReader.h"
 
using namespace std;


int main( int argc, char* argv[] )
{
    //
    // Check command line
    //
    if( argc <= 1 || strcmp( argv[ 1 ], "?" ) == 0 )
    {
        cout << "Usage: BSSDemoAppCon [-m] <image_file_name>" << endl;
        return EXIT_SUCCESS;
    }

    int nTryMultiple = 0;
    for( int n = 1; n < argc - 1; n++ )
    {
        if( argv[ n ] == (string)("-m") ) nTryMultiple = 1;
    }

    string FileName = argv[ argc - 1 ];

    //
    // Load an image
    //

    CBitmapImage BitmapImg;

    if( BitmapImg.Load8bppBitmap( FileName ) != 0 )
    {
        cerr << "Error: Unable to load the input file" << endl;
        return EXIT_FAILURE;
    }

    //
    // Start recognition
    //

    BSS_AztecInfo_Struct* pSymbolInfo = NULL;
    int nSymbolsRead = 0;
    
    int nRes = BSS_ReadAztec( BitmapImg.GetDataPtr(),
                              BitmapImg.GetWidth(),
                              BitmapImg.GetHeight(),
                              BitmapImg.GetRowByteDist(),
                              nTryMultiple,
                              &pSymbolInfo,
                              &nSymbolsRead );

    //
    // Output results
    //

    if( nRes < BSS_AZTEC_OK )
        cout << "Result   : ERROR (Code: " << nRes << ")" << endl;
    else
        cout << "Result   : " << nSymbolsRead << " symbol(s) read" << endl;

    for( int n = 0; n < nSymbolsRead; n++ )
    {
        cout << endl << "[#" << n + 1 << "]";
        cout << "  \"" << pSymbolInfo[ n ].pchData << "\"" << endl;
    }


    //
    // Release allocated resources
    //
    
    BSS_ReleaseAztecResults( pSymbolInfo, nSymbolsRead );

    return nRes;
}
